==> jc-1.4.0.tar.gz: gnu/xml/dom/DomCDATASection.h <==
// public class gnu.xml.dom.DomCDATASection

// class file dependencies
// @dep_class a7740248c7bd7f17 gnu_xml_dom_DomCDATASection
// @dep_class ac70db9f005d2722 gnu_xml_dom_DomCharacterData
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class ec2e9dfc9ae168bd gnu_xml_dom_DomText
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomText

#include "gnu/xml/dom/DomText.h"

#ifndef _JC_gnu_xml_dom_DomCDATASection_H_
#define _JC_gnu_xml_dom_DomCDATASection_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomCDATASection$sub_refs	_jc_gnu_xml_dom_DomCDATASection$sub_refs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$sub_nonrefs	_jc_gnu_xml_dom_DomCDATASection$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$refs	_jc_gnu_xml_dom_DomCDATASection$refs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$nonrefs	_jc_gnu_xml_dom_DomCDATASection$nonrefs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$object	_jc_gnu_xml_dom_DomCDATASection$object;

typedef const struct _jc_gnu_xml_dom_DomCDATASection$vmethods	_jc_gnu_xml_dom_DomCDATASection$vmethods;
typedef const struct _jc_gnu_xml_dom_DomCDATASection$vtable	_jc_gnu_xml_dom_DomCDATASection$vtable;
typedef const struct _jc_gnu_xml_dom_DomCDATASection$vtype	_jc_gnu_xml_dom_DomCDATASection$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomCDATASection$method$_init$629ade8a5a8e9c46(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_dom_DomCDATASection$method$_init$392c978db53e5030(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_char_array *, jint, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomCDATASection$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomCDATASection$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomCDATASection$vmethods {
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomCDATASection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomCharacterData$vmethods	gnu_xml_dom_DomCharacterData;
	_jc_gnu_xml_dom_DomText$vmethods	gnu_xml_dom_DomText;
	_jc_gnu_xml_dom_DomCDATASection$vmethods	gnu_xml_dom_DomCDATASection;
};

// Vtype
struct _jc_gnu_xml_dom_DomCDATASection$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomCDATASection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomCDATASection$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomCDATASection$refs {
    _jc_gnu_xml_dom_DomCDATASection$sub_refs	gnu_xml_dom_DomCDATASection;
    _jc_gnu_xml_dom_DomText$sub_refs	gnu_xml_dom_DomText;
    _jc_gnu_xml_dom_DomCharacterData$sub_refs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomCDATASection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomCDATASection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomCharacterData$sub_nonrefs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomText$sub_nonrefs	gnu_xml_dom_DomText;
    _jc_gnu_xml_dom_DomCDATASection$sub_nonrefs	gnu_xml_dom_DomCDATASection;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomCDATASection$object {
	_jc_gnu_xml_dom_DomCDATASection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomCDATASection$vtype	*vtype;
	_jc_gnu_xml_dom_DomCDATASection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomCDATASection$vtype _jc_gnu_xml_dom_DomCDATASection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomCDATASection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomCDATASection$class_object;

#endif	/* _JC_gnu_xml_dom_DomCDATASection_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomCDATASection.h <==
// public class gnu.xml.dom.DomCDATASection

// class file dependencies
// @dep_class a7740248c7bd7f17 gnu_xml_dom_DomCDATASection
// @dep_class ac70db9f005d2722 gnu_xml_dom_DomCharacterData
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class ec2e9dfc9ae168bd gnu_xml_dom_DomText
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomText

#include "gnu/xml/dom/DomText.h"

#ifndef _JC_gnu_xml_dom_DomCDATASection_H_
#define _JC_gnu_xml_dom_DomCDATASection_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomCDATASection$sub_refs	_jc_gnu_xml_dom_DomCDATASection$sub_refs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$sub_nonrefs	_jc_gnu_xml_dom_DomCDATASection$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$refs	_jc_gnu_xml_dom_DomCDATASection$refs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$nonrefs	_jc_gnu_xml_dom_DomCDATASection$nonrefs;
typedef struct _jc_gnu_xml_dom_DomCDATASection$object	_jc_gnu_xml_dom_DomCDATASection$object;

typedef const struct _jc_gnu_xml_dom_DomCDATASection$vmethods	_jc_gnu_xml_dom_DomCDATASection$vmethods;
typedef const struct _jc_gnu_xml_dom_DomCDATASection$vtable	_jc_gnu_xml_dom_DomCDATASection$vtable;
typedef const struct _jc_gnu_xml_dom_DomCDATASection$vtype	_jc_gnu_xml_dom_DomCDATASection$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomCDATASection$method$_init$629ade8a5a8e9c46(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomCDATASection$method$_init$392c978db53e5030(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomCDATASection$method$getNodeName$f5b11134ac79aed1(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomCDATASection$method_info$getNodeName$f5b11134ac79aed1;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomCDATASection$vmethods {
	struct _jc_java_lang_String$object	*(*getNodeName$f5b11134ac79aed1)(_jc_env *, struct _jc_gnu_xml_dom_DomCDATASection$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomCDATASection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomCharacterData$vmethods	gnu_xml_dom_DomCharacterData;
	_jc_gnu_xml_dom_DomText$vmethods	gnu_xml_dom_DomText;
	_jc_gnu_xml_dom_DomCDATASection$vmethods	gnu_xml_dom_DomCDATASection;
};

// Vtype
struct _jc_gnu_xml_dom_DomCDATASection$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomCDATASection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomCDATASection$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomCDATASection$refs {
    _jc_gnu_xml_dom_DomCDATASection$sub_refs	gnu_xml_dom_DomCDATASection;
    _jc_gnu_xml_dom_DomText$sub_refs	gnu_xml_dom_DomText;
    _jc_gnu_xml_dom_DomCharacterData$sub_refs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomCDATASection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomCDATASection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomCharacterData$sub_nonrefs	gnu_xml_dom_DomCharacterData;
    _jc_gnu_xml_dom_DomText$sub_nonrefs	gnu_xml_dom_DomText;
    _jc_gnu_xml_dom_DomCDATASection$sub_nonrefs	gnu_xml_dom_DomCDATASection;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomCDATASection$object {
	_jc_gnu_xml_dom_DomCDATASection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomCDATASection$vtype	*vtype;
	_jc_gnu_xml_dom_DomCDATASection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomCDATASection$vtype _jc_gnu_xml_dom_DomCDATASection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomCDATASection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomCDATASection$class_object;

#endif	/* _JC_gnu_xml_dom_DomCDATASection_H_ */
